import PropTypes from 'prop-types';
import { BASE_CLASS, EVENTS } from '../../config.js';
import useDisplayExpiredTokenError from '../../hooks/components/useDisplayExpiredTokenError.js';
import usePasswordChangeFormState from '../../hooks/components/usePasswordChangeFormState.js';
import useDomain from '../../hooks/useDomain.js';
import useEventBus from '../../hooks/useEventBus.js';
import useGetCurrentToken from '../../hooks/useGetCurrentToken.js';
import useI18n from '../../hooks/useI18n.js';
import Notification from '../Info/Notification.js';
import LoginButton from '../Input/LoginButton.js';
import PasswordInputField from '../Input/PasswordInputField.js';
import SubmitButton from '../Input/SubmitButton.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var PasswordChangeForm = function PasswordChangeForm(_ref) {
  var icons = _ref.icons;
  var i18n = useI18n();
  var domain = useDomain();
  var _useGetCurrentToken = useGetCurrentToken(),
    getCurrentToken = _useGetCurrentToken.getCurrentToken;
  var _getCurrentToken = getCurrentToken(),
    token = _getCurrentToken.token;
  var _useEventBus = useEventBus(),
    emit = _useEventBus.emit;
  var CHANGE_PASSWORD_BUTTON_CLICK = EVENTS.CHANGE_PASSWORD_BUTTON_CLICK,
    CHANGE_PASSWORD_ERROR = EVENTS.CHANGE_PASSWORD_ERROR,
    CHANGE_PASSWORD_SUCCESS = EVENTS.CHANGE_PASSWORD_SUCCESS;
  var _usePasswordChangeFor = usePasswordChangeFormState(),
    _usePasswordChangeFor2 = _usePasswordChangeFor.state,
    defaultDisabledSubmitButton = _usePasswordChangeFor2.defaultDisabledSubmitButton,
    newPassword = _usePasswordChangeFor2.newPassword,
    repeatPassword = _usePasswordChangeFor2.repeatPassword,
    isLoading = _usePasswordChangeFor2.isLoading,
    notification = _usePasswordChangeFor2.notification,
    newPasswordErrorText = _usePasswordChangeFor2.newPasswordErrorText,
    repeatPasswordErrorText = _usePasswordChangeFor2.repeatPasswordErrorText,
    setNewPassword = _usePasswordChangeFor.setNewPassword,
    setRepeatPassword = _usePasswordChangeFor.setRepeatPassword,
    setNotification = _usePasswordChangeFor.setNotification,
    setIsLoading = _usePasswordChangeFor.setIsLoading;
  useDisplayExpiredTokenError(setNotification);
  var getNewPasswordErrors = function getNewPasswordErrors(value) {
    return domain.get('validate_password_use_case').execute({
      password: value
    }).then(function (_ref2) {
      var _error$constructor;
      var error = _ref2[0];
      switch (error == null ? void 0 : (_error$constructor = error.constructor) == null ? void 0 : _error$constructor.name) {
        case undefined:
          return '';
        case 'EmptyPasswordError':
          return i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.ERRORS.EMPTY_PASSWORD');
        default:
          return i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.ERRORS.INVALID_PASSWORD');
      }
    });
  };
  var getRepeatPasswordErrors = function getRepeatPasswordErrors(repeatPasswordValue, newPasswordValue) {
    if (newPasswordValue === void 0) {
      newPasswordValue = newPassword;
    }
    if (repeatPasswordValue !== newPasswordValue && repeatPasswordValue !== '') {
      return i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.ERRORS.PASSWORDS_NOT_MATCH');
    }
    return '';
  };
  var handleChange = function handleChange(e) {
    var _e$target = e == null ? void 0 : e.target,
      value = _e$target.value;
    getNewPasswordErrors(value).then(function (errorText) {
      var repeatPasswordErrorText = getRepeatPasswordErrors(repeatPassword, value);
      setNewPassword({
        newPassword: value,
        newPasswordErrorText: errorText,
        repeatPasswordErrorText: repeatPasswordErrorText
      });
    });
  };
  var handleChangeRepeat = function handleChangeRepeat(e) {
    var _e$target2 = e == null ? void 0 : e.target,
      value = _e$target2.value;
    getNewPasswordErrors(newPassword).then(function (errorText) {
      var repeatPasswordErrorText = getRepeatPasswordErrors(value);
      setRepeatPassword({
        repeatPassword: value,
        newPasswordErrorText: errorText,
        repeatPasswordErrorText: repeatPasswordErrorText
      });
    });
  };
  var handleSubmit = function handleSubmit() {
    emit(CHANGE_PASSWORD_BUTTON_CLICK, {});
    setIsLoading(true);
    domain.get('change_password_use_case').execute({
      password: newPassword,
      token: token
    }).then(function (_ref3) {
      var error = _ref3[0];
      var isError = false;
      var text = i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.SUCCESS.PASSWORD_CHANGED');
      if (error) {
        emit(CHANGE_PASSWORD_ERROR, {
          error: error
        });
        text = i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.ERRORS.SERVER_ERROR');
        isError = true;
      } else emit(CHANGE_PASSWORD_SUCCESS, {});
      setNotification({
        text: text,
        isError: isError
      });
    });
  };
  var isSubmitButtonEnabled = function isSubmitButtonEnabled() {
    return defaultDisabledSubmitButton === false && newPasswordErrorText.length === 0 && repeatPasswordErrorText.length === 0 && repeatPassword.length > 0;
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [notification.text ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Notification, {
        notificationText: notification.text,
        isError: notification.isError
      }), /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButtons",
        children: /*#__PURE__*/_jsx(LoginButton, {})
      })]
    }) : null, !notification.text ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formInput",
        children: /*#__PURE__*/_jsx(PasswordInputField, {
          errorText: newPasswordErrorText,
          id: "new_password",
          label: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.NEW_PASSWORD_LABEL'),
          name: "new_password",
          onChange: handleChange,
          placeholder: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.PLACEHOLDER'),
          value: newPassword,
          icons: icons
        })
      }), /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formInput",
        children: /*#__PURE__*/_jsx(PasswordInputField, {
          errorText: repeatPasswordErrorText,
          id: "repeat_password",
          label: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.REPEAT_PASSWORD_LABEL'),
          name: "repeat_password",
          onChange: handleChangeRepeat,
          placeholder: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.PLACEHOLDER'),
          value: repeatPassword,
          icons: icons
        })
      }), /*#__PURE__*/_jsx("div", {
        className: BASE_CLASS + "-formButtons",
        children: /*#__PURE__*/_jsx(SubmitButton, {
          isEnabled: isSubmitButtonEnabled(),
          isLoading: isLoading,
          onClick: handleSubmit,
          children: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_2.SUBMIT_BUTTON')
        })
      })]
    }) : null]
  });
};
PasswordChangeForm.displayName = 'PasswordChangeForm';
export default PasswordChangeForm;