import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { BASE_CLASS, EVENTS } from '../../config.js';
import usePasswordResetFormState from '../../hooks/components/usePasswordResetFormState.js';
import useDomain from '../../hooks/useDomain.js';
import useEventBus from '../../hooks/useEventBus.js';
import useI18n from '../../hooks/useI18n.js';
import Notification from '../Info/Notification.js';
import ResendText from '../Info/ResendText.js';
import LoginButton from '../Input/LoginButton.js';
import SubmitButton from '../Input/SubmitButton.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var PasswordResetForm = function PasswordResetForm() {
  var _usePasswordResetForm = usePasswordResetFormState(),
    _usePasswordResetForm2 = _usePasswordResetForm.state,
    email = _usePasswordResetForm2.email,
    isLoading = _usePasswordResetForm2.isLoading,
    errorText = _usePasswordResetForm2.errorText,
    notification = _usePasswordResetForm2.notification,
    setEmail = _usePasswordResetForm.setEmail,
    setErrorText = _usePasswordResetForm.setErrorText,
    setNotification = _usePasswordResetForm.setNotification,
    setIsLoading = _usePasswordResetForm.setIsLoading;
  var i18n = useI18n();
  var domain = useDomain();
  var _useEventBus = useEventBus(),
    emit = _useEventBus.emit;
  var RESET_PASSWORD_BUTTON_CLICK = EVENTS.RESET_PASSWORD_BUTTON_CLICK,
    RESET_PASSWORD_EMAIL_VALIDATION_ERROR = EVENTS.RESET_PASSWORD_EMAIL_VALIDATION_ERROR,
    RESET_PASSWORD_ERROR = EVENTS.RESET_PASSWORD_ERROR,
    RESET_PASSWORD_RESEND_CLICK = EVENTS.RESET_PASSWORD_RESEND_CLICK,
    RESET_PASSWORD_SUCCESS = EVENTS.RESET_PASSWORD_SUCCESS;
  var getErrorText = function getErrorText(value) {
    return domain.get('validate_email_password_use_case').execute({
      email: value
    }).then(function (_ref) {
      var _error$constructor;
      var error = _ref[0];
      switch (error == null ? void 0 : (_error$constructor = error.constructor) == null ? void 0 : _error$constructor.name) {
        case undefined:
          return '';
        case 'EmptyEmailPasswordError':
          emit(RESET_PASSWORD_EMAIL_VALIDATION_ERROR, {
            email: email,
            error: error
          });
          return i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.ERRORS.EMPTY_EMAIL');
        default:
          emit(RESET_PASSWORD_EMAIL_VALIDATION_ERROR, {
            email: email,
            error: error
          });
          return i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.ERRORS.INVALID_EMAIL');
      }
    });
  };
  var handleChange = function handleChange(e) {
    var _e$target = e == null ? void 0 : e.target,
      value = _e$target.value;
    setEmail({
      email: value
    });
  };
  var executeResetPasswordUseCase = function executeResetPasswordUseCase(_ref2) {
    var onSuccessText = _ref2.onSuccessText;
    domain.get('reset_password_use_case').execute({
      email: email
    }).then(function (_ref3) {
      var error = _ref3[0];
      if (error) {
        emit(RESET_PASSWORD_ERROR, {
          email: email
        });
        setNotification({
          text: i18n.t('LOGIN_CROSS.PASSWORD_RESET.ERRORS.GENERIC_ERROR'),
          isError: true
        });
        return;
      }
      emit(RESET_PASSWORD_SUCCESS, {
        email: email
      });
      setNotification({
        text: onSuccessText,
        isError: false
      });
    });
  };
  var handleSubmit = function handleSubmit() {
    emit(RESET_PASSWORD_BUTTON_CLICK, {
      email: email
    });
    getErrorText(email).then(function (errorText) {
      if (errorText) {
        setErrorText({
          errorText: errorText
        });
        return;
      }
      setIsLoading(true);
      executeResetPasswordUseCase({
        onSuccessText: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_SENDED', {
          email: email
        })
      });
    });
  };
  var handleResend = function handleResend() {
    emit(RESET_PASSWORD_RESEND_CLICK, {
      email: email
    });
    executeResetPasswordUseCase({
      onSuccessText: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUCCESS.EMAIL_RESEND', {
        email: email
      })
    });
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [notification.text ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Notification, {
        notificationText: notification.text,
        isError: notification.isError
      }), /*#__PURE__*/_jsx(ResendText, {
        handleResend: handleResend
      })]
    }) : null, !notification.text ? /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-formInput",
      children: /*#__PURE__*/_jsx(MoleculeInputField, {
        errorText: errorText,
        id: "email",
        label: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_LABEL'),
        name: "email",
        onChange: handleChange,
        placeholder: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.EMAIL_PLACEHOLDER'),
        size: "l",
        type: "text",
        value: email
      })
    }) : null, /*#__PURE__*/_jsxs("div", {
      className: BASE_CLASS + "-formButtons",
      children: [!notification.text ? /*#__PURE__*/_jsx(SubmitButton, {
        isEnabled: true,
        isLoading: isLoading,
        onClick: handleSubmit,
        children: i18n.t('LOGIN_CROSS.PASSWORD_RESET.STEP_1.SUBMIT_BUTTON')
      }) : null, /*#__PURE__*/_jsx(LoginButton, {})]
    })]
  });
};
PasswordResetForm.displayName = 'PasswordResetForm';
export default PasswordResetForm;